@@ -21,11 +21,11 @@ Email::ExactTarget::Subscriber
 
 =head1 VERSION
 
-Version 1.3.6
+Version 1.4.0
 
 =cut
 
-our $VERSION = '1.3.6';
+our $VERSION = '1.4.0';
 
 
 =head1 SYNOPSIS
@@ -34,7 +34,7 @@ our $VERSION = '1.3.6';
 	my $subscriber = Email::ExactTarget::Subscriber->new();
 	
 	# Set attributes.
-	$subscriber->set(
+	$subscriber->set_attributes(
 		{
 			'First Name' => 'John',
 			'Last Name'  => 'Doe',
@@ -42,7 +42,7 @@ our $VERSION = '1.3.6';
 	);
 	
 	# Get attributes.
-	my $first_name = $subscriber->get('First Name');
+	my $first_name = $subscriber->get_attribute('First Name');
 	
 	# ExactTarget's subscriber ID, if applicable.
 	my $subscriber_id = $subscriber->id();
@@ -69,6 +69,8 @@ sub new
 			'staged_attributes' => {},
 			'lists'             => {},
 			'staged_lists'      => {},
+			'properties'        => {},
+			'staged_properties' => {},
 		},
 		$class
 	);
@@ -77,44 +79,6 @@ sub new
 }
 
 
-=head2 set()
-
-Sets the attributes and values for the current subscriber object.
-
-	$subscriber->set(
-		{
-			'Email Address' => $email,
-			'First Name'    => $first_name,
-		},
-		'is_live' => $boolean, #default 0
-	);
-
-The I<is_live> parameter allows specifying whether the data in the hashref are
-local only or if they are already synchronized with ExactTarget's database. By
-default, changes are considered local only and you will explicitely have to
-synchronize them using the functions of
-Email::ExactTarget::SubscriberOperations.
-
-=cut
-
-sub set ## no critic (NamingConventions::ProhibitAmbiguousNames)
-{
-	my ( $self, $attributes, %args ) = @_;
-	my $is_live = delete( $args{'is_live'} ) || 0;
-	
-	confess 'Cannot modify an object flagged as permanently deleted'
-		if $self->is_deleted_permanently();
-	
-	my $storage_key = $is_live ? 'attributes' : 'staged_attributes';
-	while ( my ( $name, $value ) = each( %$attributes ) )
-	{
-		$self->{ $storage_key }->{ $name } = $value;
-	}
-	
-	return 1;
-}
-
-
 =head2 id()
 
 Returns the Subscriber ID associated to the current Subscriber in Exact Target's
@@ -151,38 +115,7 @@ sub id
 }
 
 
-=head2 get()
-
-When passed an attribute name as a parameter, retrieves the corresponding value:
-
-	my $email = $subscriber->get( 'Email Address' );
-
-Note that this will only show the live (retrieved from ExactTarget) values. If
-changes have been staged locally, this won't retrieve the new values until you
-synchronize them using one of the methods in
-Email::ExactTarget::SubscriberOperations.
-
-#TODO: update documentation to reflect the is_live option.
-
-=cut
-
-sub get
-{
-	my ( $self, $attribute, %args ) = @_;
-	my $is_live = delete( $args{'is_live'} );
-	$is_live = 1 unless defined( $is_live );
-	
-	confess 'An attribute name is required to retrieve the corresponding value'
-		if !defined( $attribute ) || ( $attribute eq '' );
-	
-	my $storage_key = $is_live ? 'attributes' : 'staged_attributes';
-	
-	carp "The attribute '$attribute' does not exist on the Subscriber object"
-		unless exists( $self->{ $storage_key }->{ $attribute } );
-	
-	return $self->{ $storage_key }->{ $attribute };
-}
-
+=head1 MANAGING ATTRIBUTES
 
 =head2 get_attributes()
 
@@ -217,6 +150,88 @@ sub get_attributes
 }
 
 
+=head2 get_attribute()
+
+Retrieve the value corresponding to the attribute name passed as first
+parameter.
+
+	# Retrieve staged (non-synchronized with ExactTarget) attribute named
+	# 'Email Address'.
+	my $staged_email_address = $subscriber->get_attribute(
+		'Email Address',
+		is_live => 0,
+	);
+	
+	# If you've retrieved the subscriber object from ExactTarget, this
+	# retrieves the live attribute that was returned by the webservice.
+	my $live_email_address = $subscriber->get_attribute(
+		'Email Address',
+		is_live => 1,
+	);
+
+=cut
+
+sub get_attribute
+{
+	my ( $self, $attribute, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} );
+	$is_live = 1 unless defined( $is_live );
+	
+	confess 'An attribute name is required to retrieve the corresponding value'
+		if !defined( $attribute ) || ( $attribute eq '' );
+	
+	my $storage_key = $is_live
+		? 'attributes'
+		: 'staged_attributes';
+	
+	carp "The attribute '$attribute' does not exist on the Subscriber object"
+		unless exists( $self->{ $storage_key }->{ $attribute } );
+	
+	return $self->{ $storage_key }->{ $attribute };
+}
+
+
+=head2 set_attributes()
+
+Sets the attributes and values for the current subscriber object.
+
+	$subscriber->set_attributes(
+		{
+			'Email Address' => $email,
+			'First Name'    => $first_name,
+		},
+		'is_live' => $boolean, #default 0
+	);
+
+The I<is_live> parameter allows specifying whether the data in the hashref are
+local only or if they are already synchronized with ExactTarget's database. By
+default, changes are considered local only and you will explicitely have to
+synchronize them using the functions of
+Email::ExactTarget::SubscriberOperations.
+
+=cut
+
+sub set_attributes
+{
+	my ( $self, $attributes, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} ) || 0;
+	
+	confess 'Cannot modify an object flagged as permanently deleted'
+		if $self->is_deleted_permanently();
+	
+	my $storage_key = $is_live
+		? 'attributes'
+		: 'staged_attributes';
+	
+	while ( my ( $name, $value ) = each( %$attributes ) )
+	{
+		$self->{ $storage_key }->{ $name } = $value;
+	}
+	
+	return 1;
+}
+
+
 =head2 apply_staged_attributes()
 
 Moves the staged attribute changes onto the current object, effectively
@@ -246,7 +261,7 @@ sub apply_staged_attributes
 	{
 		try
 		{
-			$self->set(
+			$self->set_attributes(
 				{
 					$field => $self->{'staged_attributes'}->{ $field },
 				},
@@ -266,6 +281,45 @@ sub apply_staged_attributes
 }
 
 
+=head1 MANAGING LIST SUBSCRIPTIONS
+
+=head2 get_lists_status ()
+
+Returns the subscription status for the lists on the current object.
+
+By default, it retrieves the live data (i.e., list subscriptions synchronized
+with ExactTarget). If you want to retrieve the staged data, you can set
+I<is_live => 0> in the parameters.
+
+This function takes one mandatory parameter, which indicates whether you want
+the staged list information (lists subscribed to locally but not yet
+synchronized with ExactTarget) or the live list information (lists subscribed to
+in ExactTarget's database). The respective options are I<staged> for the staged
+information, and I<live> for the live information.
+
+	# Retrieve staged attributes (i.e., not synchronized yet with ExactTarget).
+	my $lists_status = $self->get_lists_status( 'is_live' => 0 );
+	
+	# Retrieve live attributes.
+	my $lists_status = $self->get_lists_status( 'is_live' => 1 );
+	my $lists_status = $self->get_lists_status();
+
+=cut
+
+sub get_lists_status
+{
+	my ( $self, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} );
+	$is_live = 1 unless defined( $is_live );
+	
+	my $storage_key = $is_live
+		? 'lists'
+		: 'staged_lists';
+	
+	return { %{ $self->{ $storage_key } || {} } };
+}
+
+
 =head2 set_lists_status()
 
 Stores the list IDs and corresponding subscription status.
@@ -318,43 +372,6 @@ sub set_lists_status
 }
 
 
-=head2 get_lists_status ()
-
-Returns the subscription status for the lists on the current object.
-
-By default, it retrieves the live data (i.e., list subscriptions synchronized
-with ExactTarget). If you want to retrieve the staged data, you can set
-I<is_live => 0> in the parameters.
-
-This function takes one mandatory parameter, which indicates whether you want
-the staged list information (lists subscribed to locally but not yet
-synchronized with ExactTarget) or the live list information (lists subscribed to
-in ExactTarget's database). The respective options are I<staged> for the staged
-information, and I<live> for the live information.
-
-	# Retrieve staged attributes (i.e., not synchronized yet with ExactTarget).
-	my $lists_status = $self->get_lists_status( 'is_live' => 0 );
-	
-	# Retrieve live attributes.
-	my $lists_status = $self->get_lists_status( 'is_live' => 1 );
-	my $lists_status = $self->get_lists_status();
-
-=cut
-
-sub get_lists_status
-{
-	my ( $self, %args ) = @_;
-	my $is_live = delete( $args{'is_live'} );
-	$is_live = 1 unless defined( $is_live );
-	
-	my $storage_key = $is_live
-		? 'lists'
-		: 'staged_lists';
-	
-	return { %{ $self->{ $storage_key } || {} } };
-}
-
-
 =head2 apply_staged_lists_status()
 
 Moves the staged list subscription changes onto the current object, effectively
@@ -404,6 +421,124 @@ sub apply_staged_lists_status
 }
 
 
+=head1 MANAGING PROPERTIES
+
+=head2 get_properties()
+
+Retrieve a hashref containing all the properties of the current object.
+
+By default, it retrieves the live data (i.e., properties synchronized with
+ExactTarget). If you want to retrieve the staged data, you can set
+I<is_live => 0> in the parameters.
+
+	# Retrieve staged properties (i.e., not synchronized yet with ExactTarget).
+	my $properties = $subscriber->get_properties( 'is_live' => 0 );
+	
+	# Retrieve live properties.
+	my $properties = $subscriber->get_properties( 'is_live' => 1 );
+	my $properties = $subscriber->get_properties();
+
+=cut
+
+sub get_properties
+{
+	my ( $self, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} );
+	$is_live = 1 unless defined( $is_live );
+	
+	my $storage_key = $is_live
+		? 'properties'
+		: 'staged_properties';
+	
+	# Make a copy of the attributes before returning them, in case the caller
+	# needs to modify the hash.
+	return { %{ $self->{ $storage_key } || {} } };
+}
+
+
+=head2 get_property()
+
+Retrieve the value corresponding to the property name passed as first
+parameter.
+
+	# Retrieve staged (non-synchronized with ExactTarget) property named
+	# EmailTypePreference.
+	my $staged_email_type_preference = $subscriber->get_property(
+		'EmailTypePreference',
+		is_live => 0,
+	);
+	
+	# If you've retrieved the subscriber object from ExactTarget, this
+	# retrieves the live property that was returned by the webservice.
+	my $live_email_type_preference = $subscriber->get_property(
+		'EmailTypePreference',
+		is_live => 1,
+	);
+
+=cut
+
+sub get_property
+{
+	my ( $self, $property, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} );
+	$is_live = 1 unless defined( $is_live );
+	
+	confess 'An property name is required to retrieve the corresponding value'
+		if !defined( $property ) || ( $property eq '' );
+	
+	my $storage_key = $is_live
+		? 'properties'
+		: 'staged_properties';
+	
+	carp "The property '$property' does not exist on the Subscriber object"
+		unless exists( $self->{ $storage_key }->{ $property } );
+	
+	return $self->{ $storage_key }->{ $property };
+}
+
+
+=head2 set_properties()
+
+Sets the properties and corresponding values for the current subscriber object.
+
+	$subscriber->set_properties(
+		{
+			EmailTypePreference => 'Text',
+		},
+		'is_live' => $boolean, #default 0
+	);
+
+The I<is_live> parameter allows specifying whether the data in the hashref are
+local only or if they are already synchronized with ExactTarget's database. By
+default, changes are considered local only and you will explicitely have to
+synchronize them using the functions of
+L<Email::ExactTarget::SubscriberOperations>.
+
+=cut
+
+sub set_properties
+{
+	my ( $self, $properties, %args ) = @_;
+	my $is_live = delete( $args{'is_live'} ) || 0;
+	
+	confess 'Cannot modify an object flagged as permanently deleted'
+		if $self->is_deleted_permanently();
+	
+	my $storage_key = $is_live
+		? 'properties'
+		: 'staged_properties';
+	
+	while ( my ( $name, $value ) = each( %$properties ) )
+	{
+		$self->{ $storage_key }->{ $name } = $value;
+	}
+	
+	return 1;
+}
+
+
+=head1 MANAGING ERRORS
+
 =head2 add_error()
 
 Adds a new error message to the current object.
@@ -464,6 +599,8 @@ sub errors
 }
 
 
+=head1 MANAGING DELETED SUBSCRIBERS
+
 =head2 flag_as_deleted_permanently()
 
 Flags the subscriber as having been deleted in ExactTarget's database. Any
@@ -501,6 +638,32 @@ sub is_deleted_permanently
 }
 
 
+=head1 DEPRECATED METHODS
+
+=head2 get()
+
+Please use C<get_attribute()> instead.
+
+=cut
+
+sub get
+{
+	croak 'get() has been deprecated, please use get_attribute() instead.';
+}
+
+
+=head2 set()
+
+Please use C<set_attribute()> instead.
+
+=cut
+
+sub set ## no critic (NamingConventions::ProhibitAmbiguousNames)
+{
+	croak 'set() has been deprecated, please use set_attribute() instead.';
+}
+
+
 =head1 AUTHOR
 
 Guillaume Aubert, C<< <aubertg at cpan.org> >>.
